---
title: <span class="badge object-type-scalar"></span> PetabytesPerSecond
---
# <span class="badge object-type-scalar"></span> PetabytesPerSecond

Data rate: petabytes/sec

## Definition

```python
# Data rate: petabytes/sec
PetabytesPerSecond: typing.Literal["PBs"] = "PBs"
```
